@@ -81,6 +81,9 @@ static const GtkActionEntry menu_entries[] =
     // Translators: this means 'Files that are open' (open is no verb here)
     { "OpenFiles", NULL, N_("Open _Files"), "<control>F",
       N_("View the files opened by a process"), G_CALLBACK (cb_show_open_files) },
+    { "ProcessProperties", NULL, N_("_Properties"), NULL,
+      N_("View additional information about a process"), G_CALLBACK (cb_show_process_properties) },
+
 
     { "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
       N_("Open the manual"), G_CALLBACK (cb_help_contents) },
@@ -158,6 +161,8 @@ static const char ui_info[] =
     "      <menuitem name=\"ViewMemoryMapsMenu\" action=\"MemoryMaps\" />"
     "      <menuitem name=\"ViewOpenFilesMenu\" action=\"OpenFiles\" />"
     "      <separator />"
+    "      <menuitem name=\"ViewProcessPropertiesMenu\" action=\"ProcessProperties\" />"
+    "      <separator />"
     "      <menuitem name=\"ViewRefresh\" action=\"Refresh\" />"
     "    </menu>"
     "    <menu name=\"HelpMenu\" action=\"Help\">"
@@ -184,6 +189,9 @@ static const char ui_info[] =
     "    <separator />"
     "    <menuitem action=\"MemoryMaps\" />"
     "    <menuitem action=\"OpenFiles\" />"
+    "    <separator />"
+    "    <menuitem action=\"ProcessProperties\" />"
+
     "  </popup>";
 
 
@@ -774,7 +782,8 @@ update_sensitivity(ProcData *data)
                                               "KillProcess",
                                               "ChangePriority",
                                               "MemoryMaps",
-                                              "OpenFiles" };
+                                              "OpenFiles",
+                                              "ProcessProperties" };
 
     const char * const processes_actions[] = { "ShowActiveProcesses",
                                                "ShowAllProcesses",
@@ -809,6 +818,25 @@ update_sensitivity(ProcData *data)
     }
 }
 
+void
+block_priority_changed_handlers(ProcData *data, bool block)
+{
+    gint i;
+    if (block) {
+        for (i = 0; i != G_N_ELEMENTS(priority_menu_entries); ++i) {
+            GtkRadioAction *action = GTK_RADIO_ACTION(gtk_action_group_get_action(data->action_group,
+                                             priority_menu_entries[i].name));
+            g_signal_handlers_block_by_func(action, (gpointer)cb_renice, data);
+        }
+    } else {
+        for (i = 0; i != G_N_ELEMENTS(priority_menu_entries); ++i) {
+            GtkRadioAction *action = GTK_RADIO_ACTION(gtk_action_group_get_action(data->action_group,
+                                             priority_menu_entries[i].name));
+            g_signal_handlers_unblock_by_func(action, (gpointer)cb_renice, data);
+        }
+    }
+}
+
 static void
 cb_toggle_tree (GtkAction *action, gpointer data)
 {
